@@ -1,4 +1,3 @@
-
 using System;
 using System.Collections.Generic;
 using System.Runtime.InteropServices;
@@ -18,6 +17,7 @@ namespace Tomboy
 		Gtk.ToolButton link_button;
 		NoteTextMenu text_menu;
 		Gtk.Menu plugin_menu;
+		Gtk.ImageMenuItem sync_menu_item;
 		Gtk.TextView editor;
 		Gtk.ScrolledWindow editor_window;
 		NoteFindBar find_bar;
@@ -159,13 +159,8 @@ namespace Tomboy
 				                            Gdk.ModifierType.ControlMask,
 				                            Gtk.AccelFlags.Visible);
 
-			// Have Esc key close the note window
-			if ((bool) Preferences.Get (Preferences.ENABLE_CLOSE_NOTE_ON_ESCAPE))
-				KeyPressEvent += KeyPressed;
-
-			// Watch the escape setting in GConf
-			Preferences.Client.AddNotify (Preferences.ENABLE_CLOSE_NOTE_ON_ESCAPE,
-					OnEscapeSettingChanged);
+			// Have Esc key close the find bar or note window
+			KeyPressEvent += KeyPressed;
 
 			// Increase Indent
 			global_keys.AddAccelerator (new EventHandler (ChangeDepthRightHandler),
@@ -184,6 +179,8 @@ namespace Tomboy
 
 		protected override bool OnDeleteEvent (Gdk.Event evnt)
 		{
+			Preferences.SettingChanged -= Preferences_SettingChanged;
+
 			CloseWindowHandler (null, null);
 			return true;
 		}
@@ -200,16 +197,6 @@ namespace Tomboy
 			Move (x, y);
 		}
 
-		void OnEscapeSettingChanged (object sender, NotifyEventArgs args)
-		{
-			// enable escape key
-			if ((bool) args.Value)
-				KeyPressEvent += KeyPressed;
-			// disable escape key
-			else
-				KeyPressEvent -= KeyPressed;
-		}
-
 		void KeyPressed (object sender, Gtk.KeyPressEventArgs args)
 		{
 			args.RetVal = true;
@@ -217,7 +204,10 @@ namespace Tomboy
 			switch (args.Event.Key)
 			{
 			case Gdk.Key.Escape:
-				CloseWindowHandler (null, null);
+				if (find_bar != null && find_bar.Visible)
+					find_bar.Hide ();
+				else if ((bool) Preferences.Get(Preferences.ENABLE_CLOSE_NOTE_ON_ESCAPE))
+					CloseWindowHandler (null, null);
 				break;
 			default:
 				args.RetVal = false;
@@ -507,17 +497,35 @@ namespace Tomboy
 
 			tb.Insert (new Gtk.SeparatorToolItem (), -1);
 
-			Gtk.ImageMenuItem item =
-			        new Gtk.ImageMenuItem (Catalog.GetString ("Synchronize Notes"));
-			item.Image = new Gtk.Image (Gtk.Stock.Convert, Gtk.IconSize.Menu);
-			item.Activated += SyncItemSelected;
-			item.Show ();
-			PluginMenu.Add (item);
+			sync_menu_item = new Gtk.ImageMenuItem (Catalog.GetString ("Synchronize Notes"));
+			sync_menu_item.Image = new Gtk.Image (Gtk.Stock.Convert, Gtk.IconSize.Menu);
+			sync_menu_item.Activated += SyncItemSelected;
+			sync_menu_item.Show ();
+			PluginMenu.Add (sync_menu_item);
+
+			// We might want to know when various settings are altered.
+			Preferences.SettingChanged += Preferences_SettingChanged;
+
+			// Update items based on configuration.
+			UpdateMenuItems ();
 
 			tb.ShowAll ();
 			return tb;
 		}
 
+		void Preferences_SettingChanged (object sender, EventArgs args)
+		{
+			// Update items based on configuration.
+			UpdateMenuItems ();
+		}
+
+		void UpdateMenuItems ()
+		{
+			// Is synchronization configured and active?
+			string sync_addin_id = Preferences.Get (Preferences.SYNC_SELECTED_SERVICE_ADDIN) as string;
+			sync_menu_item.Sensitive = !string.IsNullOrEmpty (sync_addin_id);
+		}
+
 		void SyncItemSelected (object sender, EventArgs args)
 		{
 			Tomboy.ActionManager ["NoteSynchronizationAction"].Activate ();
@@ -923,7 +931,7 @@ namespace Tomboy
 
 			text = text.ToLower ();
 
-			string [] words = text.Split (' ', '\t', '\n');
+			string [] words = Search.SplitWatchingQuotes (text);
 
 			current_matches =
 			        FindMatchesInBuffer (note.Buffer, words);
